@@ -384,7 +384,7 @@ void cc_param_out_str(FILE *stream, cc_param_ptr p)
     out("r", p->r);
     out("a", p->a);
     out("b", p->b);
-    printf("k %d\n", p->k);
+    fprintf(stream, "k %d\n", p->k);
     out("nk", p->nk);
     out("hk", p->hk);
 }
