@@ -37,8 +37,6 @@ int main()
     element_out_str(stdout, 0, c);
     printf("\n");
 
-    { int i, n = 10;
-	for (i=0; i<n; i++) {
     for (;;) {
 	element_random(a);
 	printf("new a = ");
@@ -56,8 +54,14 @@ int main()
     printf("sqrt(a) * sqrt(a) = ");
     element_out_str(stdout, 0, c);
     printf("\n");
-	}
-    }
+    element_invert(c, a);
+    printf("1/a = ");
+    element_out_str(stdout, 0, c);
+    printf("\n");
+    element_mul(c, c, a);
+    printf("1/a * a = ");
+    element_out_str(stdout, 0, c);
+    printf("\n");
 
     return 0;
 }
